# Generated by Django 3.0.6 on 2020-05-14 15:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bridger", "0007_asset"),
    ]

    operations = [
        migrations.RenameModel(old_name="Asset", new_name="Asset111",),
    ]
